@@ -1,25 +1,20 @@
 // ----------------------------------------------------------------------------
 // CERTI - HLA RunTime Infrastructure
-// Copyright (C) 2002, 2003  ONERA
+// Copyright (C) 2002-2005  ONERA
 //
-// This file is part of CERTI-libCERTI
-//
-// CERTI-libCERTI is free software ; you can redistribute it and/or
+// This program is free software ; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License
 // as published by the Free Software Foundation ; either version 2 of
 // the License, or (at your option) any later version.
 //
-// CERTI-libCERTI is distributed in the hope that it will be useful, but
+// This program is distributed in the hope that it will be useful, but
 // WITHOUT ANY WARRANTY ; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // Lesser General Public License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this program ; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA
-//
-// $Id: GAV.cc,v 3.9 2003/07/10 15:06:49 breholee Exp $
+// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -43,8 +38,8 @@ CAttributeHandleValuePair::CAttributeHandleValuePair()
 {
     _order = RECEIVE ;
     _transport = RELIABLE ;
-    _isPublished = RTI_FALSE ;
-    _isSubscribed = RTI_FALSE ;
+    _isPublished = RTI::RTI_FALSE ;
+    _isSubscribed = RTI::RTI_FALSE ;
     _attrib = MAX_ATTRIBUTES_PER_CLASS ;
     _value.name[0] = '\0' ;
     _value.value[0] = '\0' ;
@@ -102,7 +97,7 @@ CAttributeHandleValuePairSet::CAttributeHandleValuePairSet()
 }
 
 CAttributeHandleValuePairSet::
-CAttributeHandleValuePairSet(const AttributeHandleValuePairSet & ahvps) :
+CAttributeHandleValuePairSet(const RTI::AttributeHandleValuePairSet & ahvps) :
     _size(0), _head((CAttributeHandleValuePair *)NULL)
 {
     CAttributeHandleValuePair *cahvp ;
@@ -232,26 +227,27 @@ void CAttributeHandleValuePairSet::empty()
     assert(_size == 0);
 }
 
-AttributeHandleValuePairSet*
+RTI::AttributeHandleValuePairSet*
 CAttributeHandleValuePairSet::toAHVPS() const
 {
-    ULong longueur ;
-    CAttributeHandleValuePair *cahvp ;
-
-    AttributeHandleValuePairSet *ahvps ;
-    ahvps = AttributeSetFactory::create(_size);
+    RTI::AttributeHandleValuePairSet *ahvps ;
+    ahvps = RTI::AttributeSetFactory::create(_size);
 
     for (int i = 0 ; i<_size ; i++) {
-        cahvp = getIeme(i);
+        CAttributeHandleValuePair *cahvp = getIeme(i);
 
         if (cahvp != NULL) {
             if (&cahvp->_value != NULL) {
+                ULong longueur;
+                
                 // decodage
                 getStringToObjectLength(cahvp->_value.value, longueur);
+
                 char *valeur = new char[longueur] ;
                 valeur[0] = '\0' ;
                 stringToObject(cahvp->_value.value, valeur, longueur);
                 memcpy(cahvp->_value.value, valeur, longueur);
+                delete[] valeur;
                 /* phvps->add(cahvp->_param,
                    cahvp->_value.value,
                    (strlen(cahvp->_value.value)*sizeof(char))); */
@@ -271,14 +267,12 @@ CAttributeHandleValuePairSet::toAHVPS() const
 
 CParameterHandleValuePairSet::CParameterHandleValuePairSet()
     : _size(0), _head((CParameterHandleValuePair *) NULL)
-
 {
 }
 
 CParameterHandleValuePairSet::
-CParameterHandleValuePairSet(const ParameterHandleValuePairSet & phvps)
+CParameterHandleValuePairSet(const RTI::ParameterHandleValuePairSet &phvps)
     : _size(0), _head((CParameterHandleValuePair *) NULL)
-
 {
     CParameterHandleValuePair *cphvp = NULL ;
     ULong valueLength = 0 ;
@@ -395,7 +389,7 @@ void CParameterHandleValuePairSet::empty()
     assert(_size == 0);
 }
 
-ParameterHandleValuePairSet*
+RTI::ParameterHandleValuePairSet *
 CParameterHandleValuePairSet::toPHVPS() const
 {
     ULong longueur ;
@@ -416,6 +410,7 @@ CParameterHandleValuePairSet::toPHVPS() const
                 valeur[0] = '\0' ;
                 stringToObject(cphvp->_value.value, valeur, longueur);
                 memcpy(cphvp->_value.value, valeur, longueur);
+                delete[] valeur;
 
                 // adding new value to PHVPS
                 phvps->add(cphvp->_param, cphvp->_value.value, longueur);
@@ -423,9 +418,7 @@ CParameterHandleValuePairSet::toPHVPS() const
             else phvps->add(cphvp->_param, '\0', 0);
         }
     }
-    return (ParameterHandleValuePairSet *)phvps ;
+    return phvps ;
 }
 
-}
-
-// $Id: GAV.cc,v 3.9 2003/07/10 15:06:49 breholee Exp $
+} // namespace certi
