@@ -1,31 +1,26 @@
 // ----------------------------------------------------------------------------
 // CERTI - HLA RunTime Infrastructure
-// Copyright (C) 2002, 2003  ONERA
+// Copyright (C) 2002-2005  ONERA
 //
-// This file is part of CERTI-libCERTI
-//
-// CERTI-libCERTI is free software ; you can redistribute it and/or
+// This program is free software ; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License
 // as published by the Free Software Foundation ; either version 2 of
 // the License, or (at your option) any later version.
 //
-// CERTI-libCERTI is distributed in the hope that it will be useful, but
+// This program is distributed in the hope that it will be useful, but
 // WITHOUT ANY WARRANTY ; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // Lesser General Public License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this program ; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA
-//
-// $Id: SocketUDP.cc,v 3.8 2003/08/20 18:40:02 breholee Exp $
+// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 // ----------------------------------------------------------------------------
 
 #include <config.h>
 #include "SocketUDP.hh"
 
-#include "RTItypes.hh"
+#include "certi.hh"
 #include "PrettyDebug.hh"
 
 #include <iostream>
@@ -41,7 +36,6 @@ namespace certi {
 static pdCDebug D("SOCKUDP", "(SocketUDP) - ");
 
 // ----------------------------------------------------------------------------
-//! attach.
 void
 SocketUDP::attach(int socket_ouvert, unsigned long Adresse, unsigned int port)
     throw (NetworkError,
@@ -49,7 +43,7 @@ SocketUDP::attach(int socket_ouvert, unsigned long Adresse, unsigned int port)
 {
     assert(!_est_init_udp);
 
-    PhysicalLink = RTI_FALSE ;
+    PhysicalLink = false ;
 
     _socket_udp = socket_ouvert ;
     // Building Distant Address
@@ -59,14 +53,14 @@ SocketUDP::attach(int socket_ouvert, unsigned long Adresse, unsigned int port)
     sock_distant.sin_family = AF_INET ;
     sock_distant.sin_port = port ;
 
-    _est_init_udp = RTI_TRUE ;
+    _est_init_udp = true ;
 
     D.Out(pdDebug, "Attaching the federate to his address and to his peer...");
 }
 
 // ----------------------------------------------------------------------------
-//! bind.
-int SocketUDP::bind()
+int
+SocketUDP::bind()
 {
     assert(!_est_init_udp);
 
@@ -99,7 +93,7 @@ SocketUDP::createUDPClient(unsigned int, // port
     if ((hp_local = (struct hostent *)gethostbyname(localhost)) == NULL)
         {
             perror("SocketUDP: gethostbyname");
-            throw NetworkError();
+            throw NetworkError("");
         }
 
     bcopy((char *)hp_local->h_addr, (char *) &sock_local.sin_addr,
@@ -113,21 +107,21 @@ SocketUDP::createUDPClient(unsigned int, // port
     if (!open())
         {
             perror("SocketUDP: Open");
-            throw NetworkError();
+            throw NetworkError("");
         }
 
 
     if (!bind())
         {
             perror("SocketUDP: Bind");
-            throw NetworkError();
+            throw NetworkError("");
         }
 
     // recuperation du port lie au socket _socket_udp
     getsockname(_socket_udp, (sockaddr *)&sock_temp, &taille);
     //HPUX: getsockname(_socket_udp, (sockaddr *)&sock_temp, (int*)&taille);
     sock_local.sin_port = sock_temp.sin_port ;
-    _est_init_udp = RTI_TRUE ;
+    _est_init_udp = true ;
 }
 
 // ----------------------------------------------------------------------------
@@ -143,14 +137,14 @@ SocketUDP::createUDPServer(unsigned int port)
 
     // Building Local Address
     memset((struct sockaddr_in *) &sock_local, 0, sizeof(struct sockaddr_in));
-    hp_local = (struct hostent *)malloc(sizeof(struct hostent));
+    hp_local = (struct hostent *) malloc(sizeof(struct hostent));
 
     gethostname(localhost, 4096);
 
     hp_local = (struct hostent *) gethostbyname(localhost);
     if (hp_local == 0) {
         perror("SocketUDP: gethostbyname");
-        throw NetworkError();
+        throw NetworkError("");
     }
 
     bcopy((char *)hp_local->h_addr, (char *) &sock_local.sin_addr,
@@ -158,31 +152,27 @@ SocketUDP::createUDPServer(unsigned int port)
     sock_local.sin_family = hp_local->h_addrtype ;
     sock_local.sin_port = htons((u_short)port);
 
+    if (!open()) {
+	perror("SocketUDP: Open");
+	throw NetworkError("");
+    }
 
-    if (!open())
-        {
-            perror("SocketUDP: Open");
-            throw NetworkError();
-        }
+    if (!bind()) {
+	perror("SocketUDP: Bind");
+	throw NetworkError("");
+    }
 
-    if (!bind())
-        {
-            perror("SocketUDP: Bind");
-            throw NetworkError();
-        }
-
-    _est_init_udp = RTI_TRUE ;
+    _est_init_udp = true ;
 }
 
 // ----------------------------------------------------------------------------
-//! Constructor.
 SocketUDP::SocketUDP()
 {
-    _est_init_udp = RTI_FALSE ;
+    _est_init_udp = false ;
 
     hp_distant = NULL ;
     hp_local = NULL ;
-    PhysicalLink = RTI_TRUE ;
+    PhysicalLink = true ;
 
     BufferSize = 0 ;
     SentBytesCount = 0 ;
@@ -190,7 +180,6 @@ SocketUDP::SocketUDP()
 }
 
 // ----------------------------------------------------------------------------
-//! Destructor.
 SocketUDP::~SocketUDP()
 {
     // Fermeture
@@ -212,36 +201,31 @@ SocketUDP::~SocketUDP()
 }
 
 // ----------------------------------------------------------------------------
-//! send.
-void SocketUDP::send(void * Message, unsigned long Size)
-    throw (NetworkError,
-           NetworkSignal)
+void
+SocketUDP::send(const unsigned char * Message, size_t Size)
+    throw (NetworkError, NetworkSignal)
 {
-    long nSent = 0 ;
-    // long expected_size = Size ;
-
     D.Out(pdDebug, "Beginning to send UDP message... Size = %ld", Size);
-
     assert(_est_init_udp);
 
-    nSent = sendto(_socket_udp, (char *)Message, Size, 0,
-                   (struct sockaddr *)&sock_distant, sizeof(sock_distant));
-    if (nSent < 0) {
+    int sent = sendto(_socket_udp, Message, Size, 0,
+		      (struct sockaddr *)&sock_distant, sizeof(sock_distant));
+    if (sent < 0) {
         perror("Sendto");
-        throw NetworkError();
+        throw NetworkError("");
     };
     D.Out(pdDebug, "Sent UDP message.");
-    SentBytesCount += nSent ;
+    SentBytesCount += sent ;
 }
 
 // ----------------------------------------------------------------------------
-//! close.
-void SocketUDP::close()
+void
+SocketUDP::close()
 {
     if (_est_init_udp) {
         D.Out(pdDebug, "Closing UDP object...");
-        _est_init_udp = RTI_FALSE ;
-        if (PhysicalLink == RTI_TRUE) {
+        _est_init_udp = false ;
+        if (PhysicalLink) {
             D.Out(pdDebug, "Closing physical UDP link...");
             ::close(_socket_udp);
         }
@@ -249,7 +233,6 @@ void SocketUDP::close()
 }
 
 // ----------------------------------------------------------------------------
-//! getAddr.
 unsigned long
 SocketUDP::getAddr() const
 {
@@ -258,7 +241,6 @@ SocketUDP::getAddr() const
 }
 
 // ----------------------------------------------------------------------------
-//! getPort.
 unsigned int
 SocketUDP::getPort() const
 {
@@ -267,24 +249,24 @@ SocketUDP::getPort() const
 }
 
 // ----------------------------------------------------------------------------
-/*! Return RTI_TRUE if any data as already been read from the system socket
-  and is waiting in the internal buffer, else RTI_FALSE.
+/*! Return whether any data as already been read from the system socket
+  and is waiting in the internal buffer.
 */
-Boolean
+bool
 SocketUDP::isDataReady() const
 {
-    return ((BufferSize > 0) ? RTI_TRUE : RTI_FALSE);
+    return BufferSize > 0 ;
 }
 
 // ----------------------------------------------------------------------------
-//! open.
-int SocketUDP::open()
+int
+SocketUDP::open()
 {
-    return(((_socket_udp=socket(AF_INET, SOCK_DGRAM, 0))<0)?0:1);
+    _socket_udp = socket(AF_INET, SOCK_DGRAM, 0);
+    return _socket_udp >= 0 ;
 }
 
 // ----------------------------------------------------------------------------
-//! receive.
 void
 SocketUDP::receive(void * Message, unsigned long Size)
     throw (NetworkError, NetworkSignal)
@@ -302,7 +284,7 @@ SocketUDP::receive(void * Message, unsigned long Size)
         //HPUX:(struct sockaddr *)&sock_source, (int*) &taille);
         if (CR <= 0) {
             perror("Recvfrom");
-            throw NetworkError();
+            throw NetworkError("");
         }
         else {
             RcvdBytesCount += CR ;
@@ -312,7 +294,7 @@ SocketUDP::receive(void * Message, unsigned long Size)
 
     if (BufferSize < Size) {
         perror("Taille du Buffer inferieure a celle demandee");
-        throw NetworkError();
+        throw NetworkError("");
     }
     else {
         BufferSize -= Size ;
@@ -322,7 +304,6 @@ SocketUDP::receive(void * Message, unsigned long Size)
 }
 
 // ----------------------------------------------------------------------------
-//! returnAdress.
 unsigned long
 SocketUDP::returnAdress() const
 {
@@ -331,7 +312,6 @@ SocketUDP::returnAdress() const
 }
 
 // ----------------------------------------------------------------------------
-//! returnSocket.
 int
 SocketUDP::returnSocket() const
 {
@@ -340,13 +320,11 @@ SocketUDP::returnSocket() const
 }
 
 // ----------------------------------------------------------------------------
-//! setPort.
-void SocketUDP::setPort(unsigned int port)
+void
+SocketUDP::setPort(unsigned int port)
 {
     D.Out(pdDebug, "Affectation du Port UDP...");
     sock_local.sin_port=port ;
 }
 
-}
-
-// $Id: SocketUDP.cc,v 3.8 2003/08/20 18:40:02 breholee Exp $
+} // namespace certi
